Authors:

This specification is a draft, and has not yet been approved as an official CWL standard.

Contributors to v1.3.0-dev1:

Incorporates the work of past authors and contributors to [CWL v1.0](https://www.commonwl.org/v1.0/Workflow.html),
 [CWL v1.1](https://www.commonwl.org/v1.1/Workflow.html),
and [CWL v1.2](https://www.commonwl.org/v1.2/Workflow.html).
